/* EPLAY.H
 *
 * Definitions for the EGI player DLL.
 * Version 4.0
 * Copyright (c) 1996-2003, ITB CompuPhase
 */
#ifndef _EPLAY_H
#define _EPLAY_H

/* Every compiler uses different "default" macros to indicate the mode
 * it is in. Throughout the source, I use the Borland C++ macros, so
 * the macros of Watcom C/C++ and Microsoft Visual C/C++ are mapped to
 * those of Borland C++.
 */
#if defined(__WATCOMC__)
#  if defined(__WINDOWS__) || defined(__NT__)
#    define _Windows
#  endif
#  ifdef __386__
#    define __32BIT__
#  endif
#  if defined(_Windows) && defined(__32BIT__)
#    define __WIN32__
#  endif
#elif defined(_MSC_VER)
#  if defined(_WINDOWS) || defined(_WIN32)
#    define _Windows
#  endif
#  ifdef _WIN32
#    define __WIN32__
#    define __32BIT__
#  endif
#endif

#if !defined(_INC_WINDOWS) && !defined(__WINDOWS_H)
#  include <windows.h>
#endif

#ifdef __cplusplus
extern "C"
{
#endif

#if !defined(_EPLAY_C)
   struct LPFLIC__ {int dummy;};
   typedef const struct LPFLIC__ FAR *LPFLIC;
   typedef DWORD (FAR CALLBACK *FLIC_CALLBACK)(LPFLIC lpFlic,int code,DWORD data);
#  if defined(__WIN32__)
#    define FLICAPI     __declspec(dllimport) __stdcall
#  else
#    define FLICAPI     WINAPI
#  endif
#endif

BOOL   FLICAPI FlicClose(LPFLIC lpFlic);
HWND   FLICAPI FlicCreateWindow(LPCSTR szCaption, DWORD dwStyle, int x, int y,
                                int width, int height, HWND hwndParent,
                                int reserved);
int    FLICAPI FlicError(LPFLIC lpFlic);
long   FLICAPI FlicFindSegment(LPFLIC lpFlic, LPCSTR SegmentName);
LPVOID FLICAPI FlicGetData(LPFLIC lpFlic, int code);
HANDLE FLICAPI FlicGetHandle(LPFLIC lpFlic, HDC hdc, int code);
int    FLICAPI FlicGetParam(LPFLIC lpFlic, int code);
int    FLICAPI FlicGetParamStr(LPFLIC lpFlic, LPCSTR ParamName);
BOOL   FLICAPI FlicGetRect(LPFLIC lpFlic, int code, LPRECT lpRect);
BOOL   FLICAPI FlicIsValid(LPFLIC lpFlic);
WORD   FLICAPI FlicNextFrame(LPFLIC lpFlic);
LPFLIC FLICAPI FlicOpen(LPCSTR szFilename);
LPFLIC FLICAPI FlicOpenEx(LPCSTR szFilename, WORD wFlags, LPCSTR lpPassword);
BOOL   FLICAPI FlicOverlay(LPFLIC lpFlic, WORD Layer, WORD XPos, WORD YPos, WORD Label);
BOOL   FLICAPI FlicOverlayBitmap(LPFLIC lpFlic, WORD Layer, WORD XPos, WORD YPos,
                                 COLORREF Transparent, WORD Label,
                                 HDC hdc, HBITMAP hbmp);
BOOL   FLICAPI FlicOverlayDIB(LPFLIC lpFlic, WORD Layer, WORD XPos, WORD YPos,
                              COLORREF Transparent, WORD Label,
                              LPBITMAPINFO BmpInfo, LPVOID BitmapBits,
                              BOOL AdjustPalette);
BOOL   FLICAPI FlicOverlayPos(LPFLIC lpFlic, WORD LabelOrLayer,
                              WORD XPos, WORD YPos, int Method);
BOOL   FLICAPI FlicOverlayRemove(LPFLIC lpFlic, WORD LabelOrLayer,
                                 BOOL IncludeAbove, int Method);
BOOL   FLICAPI FlicOverlayText(LPFLIC lpFlic, WORD Layer, WORD XPos, WORD YPos,
                               COLORREF Transparent, WORD Label, LPCSTR String,
                               LPCSTR Fontname, int FontSize, int FontWeight, BOOL Italic,
                               COLORREF TextColor, COLORREF BackColor);
void   FLICAPI FlicPaint(LPFLIC lpFlic,HDC hdc,int PaintFlags);
BOOL   FLICAPI FlicPlay(LPFLIC lpFlic, HWND hwnd);
BOOL   FLICAPI FlicSetAMXInstance(HINSTANCE hinst);
BOOL   FLICAPI FlicSetCallback(LPFLIC lpFlic, FLIC_CALLBACK lpfnCallback);
BOOL   FLICAPI FlicSetData(LPFLIC lpFlic, int code, LPVOID lpData);
BOOL   FLICAPI FlicSetHandle(LPFLIC lpFlic, int code, HANDLE handle);
BOOL   FLICAPI FlicSetParam(LPFLIC lpFlic, int code, int value);
BOOL   FLICAPI FlicSetParamStr(LPFLIC lpFlic, LPCSTR ParamName, int value);
BOOL   FLICAPI FlicStop(LPFLIC lpFlic);

/* Flags for FlicOpenEx() */
#define FLIC_FLAG_MEMORY     0x0001
#define FLIC_FLAG_RESOURCE   0x0002
#define FLIC_FLAG_UNICODE    0x0004
#define FLIC_FLAG_FILEHANDLE 0x0008
#define FLIC_FLAG_DEBUG      0x0010
#define FLIC_FLAG_PASSWORD   0x0100
#define FLIC_FLAG_SCRIPT     0x0400

/* Flags for FlicPaint() */
#define FLIC_FLAG_PAINTALL   0x0001
#define FLIC_FLAG_CLIPREGION 0x0800 /* draw through region masks */

/* Parameters for FlicGetParam() and FlicSetParam() */
enum {
  FLIC_PARAM_ISPLAYING,  /* 1=FLIC file is currently playing */
  FLIC_PARAM_WIDTH,
  FLIC_PARAM_HEIGHT,
  FLIC_PARAM_NUMFRAMES,  /* number of frames in the current segment */
  FLIC_PARAM_CURFRAME,   /* current frame number */
  FLIC_PARAM_CONTINUOUS, /* segment is continuous (it has a ring frame) */
  FLIC_PARAM_SPEED,      /* playback speed, set to 0 for max. speed */
  FLIC_PARAM_DESIGNSPEED,/* design speed, read from FLIC file */
  FLIC_PARAM_REALSPEED,  /* real playback speed */
  FLIC_PARAM_MODE,       /* BitBlt mode */
  FLIC_PARAM_LOOP,       /* loop frames or only play once */
  FLIC_PARAM_NUMSEGMENTS,
  FLIC_PARAM_CURSEGMENT,
  FLIC_PARAM_XPOS,       /* position of the animation in the window */
  FLIC_PARAM_YPOS,
  FLIC_PARAM_LABEL,      /* label of the current frame (-1 if none) */
  FLIC_PARAM_CHGPAL,     /* use current palette, don't create a new one */
  FLIC_PARAM_VERSION,    /* current version of EGI player */
  FLIC_PARAM_SEGLABEL,   /* the label of the current segment */
  FLIC_PARAM_DRAWFRAME,  /* draw the frames? */
  FLIC_PARAM_FRNOTIFY,   /* notify for each frame? */
  FLIC_PARAM_MASK,       /* masks present (0=no, 1=bitmap, 2=multilevel) */
  FLIC_PARAM_ID,         /* user specified id */
  FLIC_PARAM_MSGNUM,     /* value of FLIC_NOTIFY */
  FLIC_PARAM_KEYFREQ,    /* key frame interval (0 if there are no key frames) */
  FLIC_PARAM_SKIPDELTAS, /* skip all delta frames up to the next key frame */
  FLIC_PARAM_PALMODE,    /* palette mode */
  FLIC_PARAM_IDENTPAL,   /* 1:1 mapping DIB colour table to logical palette? */
  FLIC_PARAM_SENDNOTIFY, /* send which notification messages? */
  FLIC_PARAM_COLORDEPTH, /* 8=256 colours, 15, 16 or 24 = RGB */
  FLIC_PARAM_NUMREGRECTS,/* number or recangles that form the region */
  FLIC_PARAM_LASTFRAME,  /* last frame to play */
  FLIC_PARAM_PLAYWAVE,   /* play audio chunks y/n */
  FLIC_PARAM_SYNCHRONIZE,/* speed is more important than quality */
  FLIC_PARAM_NEXTSEGMENT,/* segment that (by design) follows this one */
  FLIC_PARAM_REPEATS,    /* number of repeats for the segment */
  FLIC_PARAM_DESIGNWIDTH,/* design size, read from FLIC file */
  FLIC_PARAM_DESIGNHEIGHT,
  FLIC_PARAM_PRELOAD,    /* preload the next frame? */
  FLIC_PARAM_FRAMEBITS,  /* data chunks in last frame */
  FLIC_PARAM_XORG,       /* position of the origin in the frame's rectangle */
  FLIC_PARAM_YORG,
  FLIC_PARAM_TOTALFRAMES,/* total number of frames (over all segments) */
  FLIC_PARAM_SCALEOPTION,/* method of scaling (point-sampling, smooth Bresenham) */
  FLIC_PARAM_TRANSPCOLOR,/* transparent colour of the animation file (or -1) */
  FLIC_PARAM_OVERLAY,    /* label number of the default overlay */
  FLIC_PARAM_OVERLAYIDX, /* "active" index in overlay series */
  FLIC_PARAM_PATHGOAL,   /* segment label to move to */
};

/* Values for FLIC_PARAM_MODE */
enum {
  FLIC_MODE_BITBLT,
  FLIC_MODE_DIBTODEV,
  FLIC_MODE_STRETCHDIB,
  FLIC_MODE_WING,       /* no longer supported */
  FLIC_MODE_DIBSECTION,
  /* ----- */
  FLIC_MODES
};

/* Values for FLIC_PARAM_PALMODE */
enum {
  FLIC_PAL_ADAPT,       /* adapt to system palette */
  FLIC_PAL_ANIM,        /* use the palette from the FLIC file (default) */
  FLIC_PAL_SPECIFIC,    /* use the palette passed in by FlicSetHandle() */
  /* ----- */
  FLIC_PALMODES
};

/* Values for FLIC_PARAM_SENDNOTIFY */
#define FLIC_NOTIFY_LAST        0x001   /* notify when playing last frame (FN_LASTFRAME) */
#define FLIC_NOTIFY_LABEL       0x002   /* notify when reaching a label (FN_LABEL) */
#define FLIC_NOTIFY_FRAME       0x004   /* notify after decoding a frame (FN_FRAME) */
#define FLIC_NOTIFY_WAVE        0x008   /* notify after decoding a wave block (FN_WAVE) */
#define FLIC_NOTIFY_USERSTRING  0x010   /* notify for user string (FN_USERSTRING) */
#define FLIC_NOTIFY_SEGMENT     0x020   /* notify for starting a new segment (FN_SEGMENT) */
#define FLIC_NOTIFY_WINMSG      0x040   /* forward Windows messages? (FN_WINMSG) */
#define FLIC_NOTIFY_OVERLAY     0x080   /* notify on overlay event (FN_OVERLAY) */
#define FLIC_NOTIFY_PATHGOAL    0x100   /* notify on path goal reached (FN_PATHGOAL) */

/* Values for FLIC_PARAM_SCALEOPTION */
enum {
  FLIC_SCALE_COARSE,    /* point sampling */
  FLIC_SCALE_SMOOTH,    /* smooth Bresenham, like bi-linear interpolation */
  FLIC_SCALE_ADAPTIVE,  /* directional interpolation (adaptive) */
  /* ----- */
  FLIC_SCALEMODES
};

/* Parameters for FlicGetData() and FlicSetData() */
enum {
  FLIC_DATA_BITMAP,     /* pointer to the pixel data */
  FLIC_DATA_PALETTE,    /* pointer to the RGB table */
  FLIC_DATA_MASK,       /* pointer to the bitmap mask data */
  FLIC_DATA_BITMAPINFO, /* pointer to the BITMAPINFO structure */
  FLIC_DATA_WAVEDATA,   /* pointer to the audio samples */
  FLIC_DATA_WAVEHDR,    /* pointer to the WAVEHDR structure */
  FLIC_DATA_WAVEFORMAT, /* pointer to the WAVEFORMAT structure */
  FLIC_DATA_USERSTRING, /* pointer to unknown data */
  FLIC_DATA_USERDATA,   /* pointer to user data */
  FLIC_DATA_AMX,        /* pointer to the Small "abstract machine" */
  FLIC_DATA_DDSURFACE,  /* pointer to DirectDraw surface */
  FLIC_DATA_RGNDATA,    /* pointer to region data */
  FLIC_DATA_LABEL,      /* pointer to the last name of a label */
};

/* Parameters for FlicGetHandle() and FlicSetHandle() */
enum {
  FLIC_HANDLE_PALETTE,  /* handle to the palette */
  FLIC_HANDLE_BITMAP,   /* handle to device dependent bitmap of the frame */
  FLIC_HANDLE_MASK,     /* handle to the bitmap mask */
  FLIC_HANDLE_WINGDC,   /* no longer supported (always 0) */
  FLIC_HANDLE_WINGBMP,  /* no longer supported (always 0) */
  FLIC_HANDLE_MUTEX,    /* handle to Win32 "mutex" semaphore for bitmap */
  FLIC_HANDLE_HWND,     /* handle to window passed to FlicPlay() */
  FLIC_HANDLE_WAVE,     /* handle to global wave output device */
  FLIC_HANDLE_RGN,      /* handle to the clip region for the frame (region mask) */
};

/* Parameters for FlicGetRect() */
enum {
  FLIC_RECT_BOUNDING,   /* bounding box of frame differences */
  FLIC_RECT_MASK,       /* bounding box of the mask */
  FLIC_RECT_FIRST,      /* first rectangle of the region of frame differences */
  FLIC_RECT_NEXT,       /* next rectangle of the region of frame differences */
};

/* Flags for the "Method" parameter of several overlay functions */
enum {
  FLIC_OVL_BYLAYER,
  FLIC_OVL_BYLABEL,
  /* ----- */
  FLIC_OVLMETHODS
};

/* Returned bits for FlicNextFrame() and FLIC_PARAM_FRAMEBITS */
#define FLIC_FRAME_PAL      0x0001  /* palette needs updating */
#define FLIC_FRAME_IMG      0x0002  /* image needs updating, use FlicPaint() */
#define FLIC_FRAME_LAST     0x0004  /* last frame has played */
#define FLIC_FRAME_RING     0x0008  /* ring frame has played (reset to 2nd frame) */
#define FLIC_FRAME_LABEL    0x0010  /* a label was reached */
#define FLIC_FRAME_WAVE     0x0020  /* an audio block is ready */
#define FLIC_FRAME_USERSTRING 0x0040/* user string block */
#define FLIC_FRAME_INFO     0x0080  /* frame information block (origin/overlay) */
#define FLIC_FRAME_RGNMASK  0x0100  /* region mask data */
#define FLIC_FRAME_DECODED  0x8000  /* the frame was decoded correctly */

/* Returned values for FlicError() */
enum {
  FLIC_ERR_NONE,
  FLIC_ERR_FOPEN,
  FLIC_ERR_FORMAT,
  FLIC_ERR_FREAD,
  FLIC_ERR_MEMORY,
  FLIC_ERR_PARAM,
  FLIC_ERR_INVALID,
  FLIC_ERR_MUTEX,
  FLIC_ERR_UNSUPPORTED,
  FLIC_ERR_LOCKED,
  FLIC_ERR_WAVEOPEN,
  FLIC_ERR_FLICHANDLE,
  FLIC_ERR_GENERIC,
  /* ----- */
  FLIC_ERR_NUMBER,
};

/* Message posted to the owner window when a label is reached, a segment
 * ends, and other events...
 */
#define FLIC_COMMAND    (WM_USER+97)
#define FLIC_NOTIFY     (WM_USER+98)
enum {                  /* values for wParam upon receipt of FLIC_NOTIFY */
  FN_LABEL,             /* reached a label (LOWORD(lParam)==label) */
  FN_LASTFRAME,         /* played last frame */
  FN_FRAME,             /* played (another) frame */
  FN_WAVE,              /* digitized sound block is ready */
  FN_USERSTRING,        /* block of user data is ready */
  FN_SEGMENT,           /* new segment starts playing */
  FN_WINMSG,            /* forwarded Windows message */
  FN_OVERLAY,           /* overlay changed (add/replace/remove) */
  FN_PATHGOAL,          /* path goal reached */
};
enum {
  FC_AUTOCLOSE,         /* close animation when destroying window? */
  FC_RGNMASK,           /* use region mask? */
  FC_DRAGCLIENT,        /* move window by dragging the client area? */
  FC_IGNORECLOSE,       /* acknowledge WM_CLOSE? */
  FC_TRANSPARENT,       /* set transparent colour (layered window) */
};

/* Private WAVE format structure, for the "overlap" field */
#if defined(_WAVEFORMATEX_)
typedef struct {
  WAVEFORMATEX wfx;
  DWORD        dwOverlap;
} SEQWAVEFORMAT;
typedef SEQWAVEFORMAT       *PSEQWAVEFORMAT;
typedef SEQWAVEFORMAT FAR  *LPSEQWAVEFORMAT;
#endif

/* Utility macros */
#if !defined DIBLINESIZE
  #define DIBLINESIZE(BitCount, Width)  \
        ((((long)(Width) * (BitCount) + 31L) & ~31uL) >> 3)
#endif

/* void Cls_OnFlicNotify(HWND hwnd, int id, UINT codeNotify, UINT codeParam) */
#define HANDLE_FLIC_NOTIFY(hwnd, wParam, lParam, fn) \
    ((fn)((hwnd), (int)(HIWORD(lParam)), (wParam), (UINT)LOWORD(lParam)), 0L)
#define FORWARD_FLIC_NOTIFY(hwnd, id, codeNotify, codeParam, fn) \
    (void)(fn)((hwnd), FLIC_NOTIFY, (WPARAM)(codeNotify), (LPARAM)MAKELONG((UINT)(codeParam),(UINT)(id))

#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
class FlicWindow {
  HWND hwnd;
public:
  FlicWindow(LPCSTR szCaption="",DWORD dwStyle=0L,int x=0,int y=0,
             int width = CW_USEDEFAULT,int height = CW_USEDEFAULT,
             HWND Parent = NULL,int /*reserved*/ = 0)
    { hwnd=FlicCreateWindow(szCaption,dwStyle,x,y,width,height,Parent,0); }
  ~FlicWindow()
    { if (IsWindow(hwnd)) DestroyWindow(hwnd); }
  operator HWND() const
    { return hwnd; }
};

class FlicAnim {
  LPFLIC lpFlic;
  // class assignment is not supported; make the operator private so
  // that the compiler won't allow the assignment operator
  FlicAnim& operator=(FlicAnim&)
    { FlicClose(lpFlic); lpFlic=NULL; return *this; }
  // copy constructor is private too (i.e. it is unsupported)
  FlicAnim(FlicAnim&)
    { lpFlic=NULL; }
public:
  FlicAnim()
    { lpFlic=NULL; }
  FlicAnim(LPCSTR szFilename)
    { lpFlic=FlicOpen(szFilename); }
  FlicAnim(LPCSTR szFilename,WORD wFlags,LPCSTR lpPassword=NULL)
    { lpFlic=FlicOpenEx(szFilename,wFlags,lpPassword); }
  ~FlicAnim()
    { if (lpFlic) FlicClose(lpFlic); }
  // this lets you test whether the FLIC file was opened correctly
  operator LPFLIC() const
    { return FlicIsValid(lpFlic) ? lpFlic : NULL; }

  BOOL Close()
    { return FlicClose(lpFlic) ? lpFlic=NULL,1 : 0; }
  int  Error() const
    { return FlicError(lpFlic); }
  long FindSegment(LPCSTR SegmentName) const
    { return FlicFindSegment(lpFlic,SegmentName); }
  LPVOID GetData(int code) const
    { return FlicGetData(lpFlic,code); }
  HANDLE GetHandle(HDC hdc,int code) const
    { return FlicGetHandle(lpFlic,hdc,code); }
  int  GetParam(int code) const
    { return FlicGetParam(lpFlic,code); }
  BOOL GetRect(int code,LPRECT lpRect) const
    { return FlicGetRect(lpFlic,code,lpRect); }
  WORD NextFrame()
    { return FlicNextFrame(lpFlic); }
  BOOL Open(LPCSTR szFilename,WORD wFlags=0,LPCSTR lpPassword=NULL)
    { if (lpFlic) FlicClose(lpFlic);
      return (lpFlic=FlicOpenEx(szFilename,wFlags,lpPassword))!=NULL; }
  BOOL Overlay(WORD Layer,WORD XPos,WORD YPos,WORD Label)
    { return FlicOverlay(lpFlic,Layer,XPos,YPos,Label); }
  BOOL OverlayBitmap(WORD Layer,WORD XPos,WORD YPos,COLORREF Transparent,WORD Label,
                     HDC hdc,HBITMAP hbmp)
    { return FlicOverlayBitmap(lpFlic,Layer,XPos,YPos,Transparent,Label,hdc,hbmp); }
  BOOL OverlayDIB(WORD Layer,WORD XPos,WORD YPos,COLORREF Transparent,WORD Label,
                  LPBITMAPINFO BmpInfo,LPVOID BitmapBits,BOOL AdjustPalette=TRUE)
    { return FlicOverlayDIB(lpFlic,Layer,XPos,YPos,Transparent,Label,BmpInfo,BitmapBits,AdjustPalette); }
  BOOL OverlayPos(WORD LabelOrLayer,WORD XPos,WORD YPos,int Method=FLIC_OVL_BYLABEL)
    { return FlicOverlayPos(lpFlic,LabelOrLayer,XPos,YPos,Method); }
  BOOL OverlayRemove(WORD LabelOrLayer,BOOL IncludeAbove=FALSE,int Method=FLIC_OVL_BYLABEL)
    { return FlicOverlayRemove(lpFlic,LabelOrLayer,IncludeAbove,Method); }
  BOOL OverlayText(WORD Layer,WORD XPos,WORD YPos,COLORREF Transparent,WORD Label,
                   LPCSTR String,LPCSTR Fontname="System",int FontSize=16,
                   int FontWeight=FW_NORMAL,BOOL Italic=FALSE,
                   COLORREF TextColor=RGB(255,255,255),COLORREF BackColor=RGB(0,0,0))
    { return FlicOverlayText(lpFlic,Layer,XPos,YPos,Transparent,Label,String,Fontname,FontSize,FontWeight,Italic,TextColor,BackColor); }
  void Paint(HDC hdc,int PaintFlags=FLIC_FLAG_PAINTALL)
    { FlicPaint(lpFlic,hdc,PaintFlags); }
  BOOL Play(HWND hwnd=NULL)
    { return FlicPlay(lpFlic,hwnd); }
  BOOL SetCallback(FLIC_CALLBACK lpfnCallback=NULL)
    { return FlicSetCallback(lpFlic,lpfnCallback); }
  BOOL SetData(int code,LPVOID lpData)
    { return FlicSetData(lpFlic,code,lpData); }
  BOOL SetHandle(int code,HANDLE handle)
    { return FlicSetHandle(lpFlic,code,handle); }
  BOOL SetParam(int code,int value)
    { return FlicSetParam(lpFlic,code,value); }
  BOOL Stop()
    { return FlicStop(lpFlic); }
  /* extra methods that map to the generic functions */
  BOOL IsPlaying() const
    { return (BOOL)FlicGetParam(lpFlic,FLIC_PARAM_ISPLAYING); }
  HPALETTE GetHPalette() const
    { return (HPALETTE)FlicGetHandle(lpFlic,NULL,FLIC_HANDLE_PALETTE); }
  WORD Height() const
    { return (WORD)FlicGetParam(lpFlic,FLIC_PARAM_HEIGHT); }
  WORD Width() const
    { return (WORD)FlicGetParam(lpFlic,FLIC_PARAM_WIDTH); }
  int XPos() const
    { return FlicGetParam(lpFlic,FLIC_PARAM_XPOS); }
  int YPos() const
    { return FlicGetParam(lpFlic,FLIC_PARAM_YPOS); }
  BOOL Reset()
    { return FlicSetParam(lpFlic,FLIC_PARAM_CURFRAME,0); }
  BOOL SetXYPos(int x, int y)
    { return FlicSetParam(lpFlic,FLIC_PARAM_XPOS,x) && FlicSetParam(lpFlic,FLIC_PARAM_YPOS,y); }
  BOOL SetSize(int width, int height)
    { return FlicSetParam(lpFlic,FLIC_PARAM_WIDTH,width) && FlicSetParam(lpFlic,FLIC_PARAM_HEIGHT,height); }
};
#endif

#endif /* _EPLAY_H */
